==> qmmp_1.1.4.orig.tar.bz2: qmmp-1.1.4/src/plugins/FileDialogs/QmmpFileDialog/translations/qmmp_file_dialog_plugin_sr_BA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sr_BA">
<context>
    <name>QmmpFileDialog</name>
    <message>
        <location filename="../qmmpfiledialog.ui" line="13"/>
        <source>Add Files</source>
        <translation>Додавање фајлова</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="37"/>
        <source>Up</source>
        <translation>Горе</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="40"/>
        <location filename="../qmmpfiledialog.ui" line="53"/>
        <location filename="../qmmpfiledialog.ui" line="72"/>
        <location filename="../qmmpfiledialog.ui" line="97"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="50"/>
        <source>List view</source>
        <translation>Сажети приказ</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="69"/>
        <source>Detailed view</source>
        <translation>Приказ детаља</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="94"/>
        <source>Close dialog on add</source>
        <translation>Затвори дијалог по додавању</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="177"/>
        <source>File name:</source>
        <translation>Име фајла:</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="193"/>
        <source>Add</source>
        <translation>Додај</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="200"/>
        <source>Files of type:</source>
        <translation>Типови фајлова:</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="226"/>
        <source>Close</source>
        <translation>Затвори</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogFactory</name>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="69"/>
        <location filename="../qmmpfiledialog.cpp" line="79"/>
        <source>Qmmp File Dialog</source>
        <translation>Кумп дијалог фајлова</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="78"/>
        <source>About Qmmp File Dialog</source>
        <translation>О Кумповом дијалогу фајлова</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="80"/>
        <source>Written by:
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Аутори:
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="83"/>
        <source>Some code is copied from the Qt library</source>
        <translation>Дио кôда је преузет из Кут библиотеке</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogImpl</name>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="250"/>
        <source>Add</source>
        <translation>Додај</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="263"/>
        <source>Save</source>
        <translation>Сачувај</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="277"/>
        <source>Directories</source>
        <translation>Фасцикле</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="446"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 већ постоји.
Желите ли да га пребришете?</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/FileDialogs/QmmpFileDialog/translations/qmmp_file_dialog_plugin_sr_BA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sr_BA">
<context>
    <name>QmmpFileDialog</name>
    <message>
        <location filename="../qmmpfiledialog.ui" line="14"/>
        <source>Add Files</source>
        <translation>Додавање фајлова</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="177"/>
        <source>Up</source>
        <translation>Горе</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="180"/>
        <location filename="../qmmpfiledialog.ui" line="193"/>
        <location filename="../qmmpfiledialog.ui" line="212"/>
        <location filename="../qmmpfiledialog.ui" line="237"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="190"/>
        <source>List view</source>
        <translation>Сажети приказ</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="209"/>
        <source>Detailed view</source>
        <translation>Приказ детаља</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="234"/>
        <source>Close dialog on add</source>
        <translation>Затвори дијалог по додавању</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="106"/>
        <source>File name:</source>
        <translation>Име фајла:</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="122"/>
        <source>Add</source>
        <translation>Додај</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="129"/>
        <source>Files of type:</source>
        <translation>Типови фајлова:</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="155"/>
        <source>Close</source>
        <translation>Затвори</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogFactory</name>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="70"/>
        <location filename="../qmmpfiledialog.cpp" line="80"/>
        <source>Qmmp File Dialog</source>
        <translation>Кумп дијалог фајлова</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="79"/>
        <source>About Qmmp File Dialog</source>
        <translation>О Кумповом дијалогу фајлова</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="81"/>
        <source>Written by:
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Аутори:
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="84"/>
        <source>Some code is copied from the Qt library</source>
        <translation>Дио кôда је преузет из Кут библиотеке</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogImpl</name>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="262"/>
        <source>Add</source>
        <translation>Додај</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="275"/>
        <source>Save</source>
        <translation>Сачувај</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="289"/>
        <source>Directories</source>
        <translation>Фасцикле</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="476"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 већ постоји.
Желите ли да га пребришете?</translation>
    </message>
</context>
</TS>
